@@ -31,7 +31,7 @@ class Vn:
         #----------------------------------------------------------------
         # Load Network API Json
         self.network_api_json: dict = None
-        with importlib.resources.open_text("veevatools", "data.json") as file:
+        with importlib.resources.open_text("veevanetwork", "network_api_v25.json") as file:
             self.network_api_json = json.load(file)
         # with open('network_api_v25.json', encoding="utf-8") as file:
         #     self.network_api_json = json.load(file)
